@echo off
REM ********************************************************************
REM *
REM *  Name:            LAUNCH-YourPS1NameHere.cmd
REM *  Author:          Darwin Sanoy
REM *  Updates:         http://csi-windows.com/toolkit
REM *  Bug Reports &
REM *  Enhancement Req: http://CSI-Windows.com/about/contact-us
REM *
REM *  Built/Tested On: 64-bit Win7
REM *
REM *  COPYRIGHT NOTICE:  This script is Copyrighted by Synaptic Fireworks, LLC
REM *    If you received this script directly from CSI-Windows.com as a result
REM *    training, a conference or personal contact with staff, then you are 
REM *    allowed to use the script in your organization.
REM *
REM *    No public or private redistribution of this code is allowed.  This     
REM *    includes, but is not limited to, email, posting to websites, blogs 
REM *    or forums.
REM *
REM *    This copyright notice and all comments in the script must remain intact.
REM *
REM *  PURPOSE:
REM *    This script makes it easy to send links to PowerShell Scripts by:
REM *      [a] allowing clicking of a emailed or IM'ed link
REM *      [b] which launches PowerShell against a script (explorer clicking normally opens ps1's in notepad)
REM *      [c] can be configured to request elevation
REM *      [d] can be configured with arguments to pass to the .PS1 in case there are multiple launch senarios

REM *      [e] IMPORTANT: This CMD automatically searches for a matching .ps1.  
REM *          A ".ps1" filename matches if it's name matches all characters of the CMD name *AFTER THE DASH*
REM *          So "MyCoolScript.ps1" would be found by this CMD if the CMD were named "LAUNCH-MyCoolScript.ps1"
REM *          or "Uninstall-MyCoolScript.ps1" or "Install-MyCoolScript.ps1" etc.

REM *  CUSTOMIZATION AND USAGE:

REM *    Scenario 1: Run a .PS1 with no need to elevate.
REM *      [a] Name this script "sometext-thenameofthescript.cmd"

REM *      You are DONE - this script will launch the powershell named "thenameofthescript.ps1"

REM *    Scenario 2: Run a .PS1 with an elevation request to the user
REM *      [a] Name this script "sometext-thenameofthescript.cmd"
REM *      [b] Below change "RequiresElevation=FALSE" to "RequiresElevation=TRUE" (no quotes)

REM *      You are DONE - this script will launch the powershell named "thenameofthescript.ps1" and ask the user to elevate.

REM *    Scenario 3: Run a .PS1 with arguments
REM *      [a] Configure according to Scenario 1 or 2 above
REM *      [b] Below change env var "SET PSScriptArgs=" to "PSScriptArgs= -yourarg1 "hi" -yourarg2" (no *surrounding* quotes)

REM *    Other Support Customization Options:
REM *      [*] Control the exact .PS1 script name by changing env var RunPSHName
REM *      [*] Launching 32-bit on 64-bit (better to do it inside the script with CSI_AutoSwitchBitness.ps1 code)
REM *      [*] Hide or show first launch window (on elevated launches) via env var HideFirstPowerShellWindow below (good for debugging)
REM *      [*] Allow script run window to stay open (for debugging) via env var PSLaunchOptions below 
REM *      [*] Control PowerShell launc options via env var PSLaunchOptions below 


REM *  Revision History:
REM *    11/16/13 - 1.1 - inital version (djs)
REM *
REM *******************************************************************

REM Set whether to request to elevate the script (User must be admin)
Set RequiresElevation=FALSE

REM Set Arguments (if any) for final script (e.g. "-FakeDemoOption" - with no quotes)
Set PSScriptArgs=

REM Set a manual script name override if auto name search is not appropriate
REM include ".ps1" extension, but not path.
Set RunPSHName=

REM Alternate the "REMs" on the next two lines for debugging. 
REM Set HideFirstPowerShellWindow=-noexit 
Set HideFirstPowerShellWindow=-windowstyle hidden

REM set to "Syswow64" (noquotes) for 32-bit execution on 64-bit
REM It is better to do execution bitness control *INSIDE* the script.
Set SysBitnessFolder=System32

REM add "-noexit" (without quotes) to the next line to leave actual script window open for debugging script
Set PSLaunchOptions= -NoLogo -NoProfile -ExecutionPolicy Bypass

SET ScriptScreenName=*** CSI-Windows.com PowerShell Easy Launcher ***


REM ****** MAIN SCRIPT *******
Cls & Echo. & echo %ScriptScreenName% & echo.

echo %0 | findstr /R /C:" .* .*" && Set pathspaces=TRUE
If "%PATHSPACES%" EQU "TRUE" ( echo. & Echo Sorry, this script cannot work if there are spaces in the path, exiting... & echo. & Pause & Exit)

REM automatically determine PSH name by stripping everything before the dash in this script's name
REM E.g. Script name = "Launch-ABC.cmd" then RunPSHName = "ABC.ps1"


If "%RunPSHName%" equ "" (
  FOR /F "tokens=1,2 delims=-" %%A in ("%~n0") do (Set SearchName=%%B
  If Exist "%~dp0%%B.ps1" (Set RunPSHName=%~dp0%%B.ps1
  ) Else (Set InvalidScriptName=TRUE))

) Else (
  If Exist "%~dp0%RunPSHName%" (Set RunPSHNameTemp=~dp0%RunPSHName% && Set RunPSHName=~dp0%RunPSHNameTemp% 
  ) Else (Set InvalidScriptName=TRUE)
)

if "%InvalidScriptName%" equ "TRUE" (echo Script Name: "%RunPSHName%" & Echo No valid script name specified, exiting... & echo. & pause & exit)

NET SESSION >NUL 2>&1
If %ERRORLEVEL% NEQ 0 IF "%RequiresElevation%" equ "TRUE" (
  %SystemRoot%\%SysBitnessFolder%\WindowsPowerShell\v1.0\powershell.exe %HideFirstPowerShellWindow% -nologo -noprofile -executionpolicy bypass -command "start-process -verb 'runas' -filepath $env:SystemRoot\$env:SysBitnessFolder\WindowsPowerShell\v1.0\powershell.exe -argumentlist "" %PSLAUNCHOPTIONS% -file """"""%RunPSHName%"""""" %PSScriptArgs%"""
  goto :DONE
) 

:ELSECALLWITHOUTELEV
  %SystemRoot%\%SysBitnessFolder%\WindowsPowerShell\v1.0\powershell.exe %PSLaunchOptions% -file ""%RunPSHName%"" %PSScriptArgs%

:DONE